#
# spec file for package vala-panel
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           vala-panel
Version:        0.3.5
Release:        5.5
Summary:        A Gtk3 desktop panel based on Vala
License:        GPL-3.0+
Group:          System/GUI/Other
Url:            https://github.com/rilian-la-te/vala-panel
Source:         https://github.com/rilian-la-te/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  pkg-config
BuildRequires:  vala >= 0.24
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12.0
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.2.0
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.4.0
Recommends:     %{name}-lang = %{version}
Recommends:     %{name}-plugins-base = %{version}
Recommends:     %{name}-sntray = %{version}
Suggests:       %{name}-appmenu = %{version}
Suggests:       %{name}-plugins-wnck = %{version}

%description
Vala Panel is a desktop panel written in Vala and Gtk3.
Initially it was a fork of LXPanel but 0.2.0 is completely
rewritten in Vala. It offers same functionality as LXPanel but:
 * It has a slightly bigger memory usage.
 * X11 dependency is stripped from panel core (but it is not tested
   on another display servers, such as Wayland and Mir, right now).
 * Some of former LXPanel plugins are separate binaries now
   and live in another packages (volume applet for example).

%lang_package

%package devel
Summary:        Development files for vala-panel
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       pkg-config
Requires:       pkgconfig(gtk+-3.0) >= 3.12.0
Requires:       pkgconfig(libpeas-1.0) >= 1.2.0
Requires:       pkgconfig(libwnck-3.0) >= 3.4.0

%description devel
Vala Panel is a desktop panel written in Vala and Gtk3.

This is a development package for vala-panel.

%package plugins-base
Summary:        Plugins for vala-panel -- non-X11 plugins
Group:          System/GUI/Other

%description plugins-base
This package contains main plugins for vala-panel: clock,
launchbar, applications menu and so on.

%package plugins-wnck
Summary:        Plugins for vala-panel -- X11 plugins
Group:          System/GUI/Other

%description plugins-wnck
This package contains X11 plugins for vala-panel: tasklist,
system tray, and others.

%prep
%setup -q
%if 0%{?suse_version} != 1320
# Use upstream glib-2.0.vapi.
rm vapi/glib-2.0.vapi
%endif

%build
%cmake \
  -DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
  -DGSETTINGS_COMPILE=OFF
make %{?_smp_mflags}

%install
%cmake_install
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}

%post
%icon_theme_cache_post
%glib2_gsettings_schema_post
/sbin/ldconfig

%postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun
/sbin/ldconfig

%post plugins-base
%glib2_gsettings_schema_post

%postun plugins-base
%glib2_gsettings_schema_postun

%post plugins-wnck
%glib2_gsettings_schema_post

%postun plugins-wnck
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc LICENSE README.md
%config %{_sysconfdir}/xdg/vala-panel/
%{_mandir}/man?/vala-panel.?%{?ext_man}
%{_bindir}/vala-panel
%{_datadir}/glib-2.0/schemas/org.valapanel.gschema.xml
%{_libdir}/libvalapanel.so.*
%{_datadir}/vala/
%{_datadir}/vala-panel/
%{_datadir}/glib-2.0/schemas/org.valapanel.toplevel.gschema.xml
%{_datadir}/icons/hicolor/*/apps/vala-panel.*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%{_libdir}/libvalapanel.so
%{_includedir}/vala-panel/
%{_libdir}/pkgconfig/vala-panel.pc

%files plugins-base
%defattr(-,root,root)
%{_datadir}/glib-2.0/schemas/org.valapanel.builtin.gschema.xml
%{_datadir}/glib-2.0/schemas/org.valapanel.plugins.gschema.xml
%dir %{_libdir}/vala-panel/
%dir %{_libdir}/vala-panel/applets/
%{_libdir}/vala-panel/applets/libclock.so
%{_libdir}/vala-panel/applets/libcpu.so
%{_libdir}/vala-panel/applets/libdirmenu.so
%{_libdir}/vala-panel/applets/libkbled.so
%{_libdir}/vala-panel/applets/liblaunchbar.so
%{_libdir}/vala-panel/applets/libmenumodel.so
%{_libdir}/vala-panel/applets/libseparator.so
%{_libdir}/vala-panel/applets/libmonitors.so
%{_libdir}/vala-panel/applets/clock.plugin
%{_libdir}/vala-panel/applets/cpu.plugin
%{_libdir}/vala-panel/applets/dirmenu.plugin
%{_libdir}/vala-panel/applets/kbled.plugin
%{_libdir}/vala-panel/applets/launchbar.plugin
%{_libdir}/vala-panel/applets/menumodel.plugin
%{_libdir}/vala-panel/applets/separator.plugin
%{_libdir}/vala-panel/applets/monitors.plugin

%files plugins-wnck
%defattr(-,root,root)
%{_datadir}/glib-2.0/schemas/org.valapanel.X.gschema.xml
%{_libdir}/vala-panel/applets/libxembed.so
%{_libdir}/vala-panel/applets/libdeskno.so
%{_libdir}/vala-panel/applets/libtasklist.so
%{_libdir}/vala-panel/applets/libwincmd.so
%{_libdir}/vala-panel/applets/libpager.so
%{_libdir}/vala-panel/applets/libbuttons.so
%{_libdir}/vala-panel/applets/xembed.plugin
%{_libdir}/vala-panel/applets/deskno.plugin
%{_libdir}/vala-panel/applets/tasklist.plugin
%{_libdir}/vala-panel/applets/wincmd.plugin
%{_libdir}/vala-panel/applets/pager.plugin
%{_libdir}/vala-panel/applets/buttons.plugin

%changelog
* Sat May  7 2016 sor.alexei@meowr.ru
- Fix build by using upstream glib-2.0.vapi.
* Wed Jun 24 2015 cdenicolo@suse.com
- correct license is GPL-3.0+, see LICENSE-file
* Fri Jun 19 2015 sor.alexei@meowr.ru
- Initial package.
